#! /bin/sh
# Script to build a Slackware package for wxmaxima (needed for wxmaxima)
# You must have wxMaxima-0.5.4.tar.gz in the current directory.
# This script may fail if the path pointing to the current directory
# contains special character (such as space,...). It has been tested with the full
# installation of Slackware 10.0 
# This script is in the public domain 
# Author (of this script): Olivier Esser, olive_esseret@yahoo.com)


SRC=wxMaxima-0.5.4.tar.gz
PKGNAME=wxmaxima-0.5.4-i486-1.tgz
BUILDSCRIPT=/usr/src/slackbuilds/wxMaxima-0.5.4/build.sh
PKGSNAME=wxmaxima
INSTALLDIR=/usr
DOC=$INSTALLDIR/doc/wxMaxima-0.5.4

error() {
    echo "$1 failed, exiting..." 1>&2
    exit 1
}

# Strip recursively all files and libraries in the given directory
stripall() {
    for f in `find $1 -type f` ; do
	if file $f | grep -q 'not stripped' ; then
	    strip -s $f
	fi
    done
}


umask 0022
export CFLAGS="-march=i486"
export CXXFLAGS="-march=i486"
BUILD=/tmp/wxmaxima.build
PKG=/tmp/wxmaxima.pkg
rm -rf -- $BUILD $PKG
mkdir $BUILD
mkdir $PKG
CURDIR=$PWD
cd $BUILD
tar -zxf $CURDIR/$SRC
# cd to the directory tar has created
cd *
./configure --prefix=$INSTALLDIR || error configure
make || error make
make install DESTDIR=$PKG || error "make install"
chown -R root:bin $PKG/$INSTALLDIR/bin
mkdir -p $PKG/$DOC
cp AUTHORS COPYING NEWS README config.log $PKG/$DOC
cp $CURDIR/wxmaxima-0.5.4-i486-1.txt $PKG/$DOC/README.Slackware-package 
cd $CURDIR
mkdir -p `dirname $PKG/$BUILDSCRIPT`
cp $0 $PKG/$BUILDSCRIPT
cd $PKG
stripall .
mkdir install
cat > install/slack-desc <<EOF
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

        |-----handy-ruler------------------------------------------------------|
wxmaxima: wxmaxima. A GUI for maxima.
wxmaxima:
wxmaxima: Maxima is a symbolic computation program. It is full featured, doing
wxmaxima: symbolic manipulation of polynomials, matrices, rational, functions,
wxmaxima: integration, Todd-coxeter, graphing, bigfloats. 
wxmaxima: This package contains wxmaxima: a GUI interface of maxima.
wxmaxima: Most of maxima functions are accessible through menus, some have
wxmaxima: dialogs. Output will be very nicely formated.
wxmaxima: This package requires maxima-5.9.1-noarch-1.tgz and
wxmaxima: wxGTK-2.4.2-i486-1.tgz
EOF
cd $PKG
makepkg -l n -c n $CURDIR/$PKGNAME
